@@ -3,7 +3,7 @@ import os.path
 
 from jnpr.junos.factory.factory_loader import FactoryLoader
 
-__all__ = ['loadyaml', 'FactoryLoader']
+__all__ = ["loadyaml", "FactoryLoader"]
 
 
 def loadyaml(path):
@@ -28,6 +28,6 @@ def loadyaml(path):
       ...
     """
     # if no extension is given, default to '.yml'
-    if os.path.splitext(path)[1] == '':
-        path += '.yml'
-    return FactoryLoader().load(yaml.load(open(path, 'r'), Loader=yaml.FullLoader))
+    if os.path.splitext(path)[1] == "":
+        path += ".yml"
+    return FactoryLoader().load(yaml.load(open(path, "r"), Loader=yaml.FullLoader))
